"""
                       _
  __ _  ___   ___   __| |_ __ _   _ _ __  ___
 / _` |/ _ \ / _ \ / _` | '__| | | | '_ \/ __|
| (_| | (_) | (_) | (_| | |  | |_| | | | \__ \\
 \__, |\___/ \___/ \__,_|_|   \__,_|_| |_|___/  %s
 |___/

 Author: Noel Dawe

"""
__version__ = '2.7'
__url__ = 'http://ndawe.github.com/goodruns'
__repo_url__ = 'https://github.com/ndawe/goodruns/'
__download_url__ = 'http://pypi.python.org/packages/source/g/goodruns/' \
                   'goodruns-%s.tar.gz' % __version__
__doc__ = __doc__ % __version__

# optional dependencies
USE_LXML = False
USE_YAML = False
